=== modified file 'README'
--- README	2006-05-14 15:59:00 +0000
+++ README	2006-05-20 16:05:21 +0000
@@ -10,11 +10,4 @@
 If on an Ubuntu system, you must install python-nautilus.  This package
 assumes bzr 0.8.  After installation, restart nautilus.
 
-Optional Dependencies
-=====================
-
- * bzrk (plugin for bzr)
- * gannotate (plugin for bzr)
-
-
-
+A lot of functionality requires the 'bzr-gtk' plugin for Bazaar to be installed.

=== modified file 'nautilus-bzr.py'
--- nautilus-bzr.py	2006-05-19 21:48:54 +0000
+++ nautilus-bzr.py	2006-05-20 16:05:21 +0000
@@ -72,7 +72,7 @@
 
         from bzrlib.plugins.gtk.viz.diffwin import DiffWindow
         window = DiffWindow()
-        window.set_diff("Working Tree", tree, tree.branch.repository.revision_tree(tree.branch.last_revision()))
+        window.set_diff(tree.branch, tree, tree.branch.revision_tree())
         window.show()
 
         return
@@ -117,9 +117,24 @@
 
         vis = cmd_gannotate()
         vis.run(file)
-
-        return
  
+    def commit_cb(self, menu, vfs_file=None):
+        # We can only cope with local files
+        if vfs_file.get_uri_scheme() != 'file':
+            return
+
+        file = vfs_file.get_uri()
+        try:
+            tree, path = WorkingTree.open_containing(file)
+        except NotBranchError:
+            return
+
+        from bzrlib.plugins.gtk.commit.gcommit import GCommitDialog
+        dialog = GCommitDialog(tree)
+        dialog.set_title(path + " - Commit")
+        if dialog.run() != gtk.RESPONSE_CANCEL:
+            Commit().commit(working_tree=wt,message=dialog.message,
+                            specific_files=dialog.specific_files)
 
     def log_cb(self, menu, vfs_file):
         # We can only cope with local files
@@ -148,16 +163,23 @@
                                  'Create new Bazaar tree',
                                  'Create new Bazaar tree in this folder')
             item.connect('activate', self.newtree_cb, vfs_file)
-            return item,
+            return item
 
+        items = []
         if have_gtkplugin:
             item = nautilus.MenuItem('BzrNautilus::log',
                                  'Log',
                                  'Show Bazaar history')
             item.connect('activate', self.log_cb, vfs_file)
-            return item,
-
-        return
+            items.append(item)
+
+            item = nautilus.MenuItem('BzrNautilus::commit',
+                                 'Commit',
+                                 'Commit Changes')
+            item.connect('activate', self.commit_cb, vfs_file)
+            items.append(item)
+
+        return items
 
 
     def get_file_items(self, window, files):
@@ -208,8 +230,6 @@
                     item.connect('activate', self.log_cb, vfs_file)
                     items.append(item)
 
-                    # FIXME: Don't show if there are no changes
-                    # to the current file...
                     item = nautilus.MenuItem('BzrNautilus::diff',
                                      'Diff',
                                      'Show differences')
@@ -228,5 +248,11 @@
                                  'Annotate File Data')
                     item.connect('activate', self.annotate_cb, vfs_file)
                     items.append(item)
+
+                    item = nautilus.MenuItem('BzrNautilus::commit',
+                                 'Commit',
+                                 'Commit Changes')
+                    item.connect('activate', self.commit_cb, vfs_file)
+                    items.append(item)
     
         return items

